View source: R/binarize-strategy.R
| binarize_largest_gap | R Documentation |
Creates a binarization strategy that reduces multiclass nodes to binary by projecting group means and splitting at the largest gap. Default for classification specs.
binarize_largest_gap()
A binarize_strategy object.
pptr, pprf, binarize_disabled
binarize_largest_gap()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.