View source: R/grouping-strategy.R
| grouping_by_cutpoint | R Documentation |
Creates a grouping strategy for regression trees: observations are split by the cutpoint in projected space, then each child's observations are sorted by the continuous response and median-split into 2 new groups for the next projection-pursuit step. This is the default grouping strategy for regression.
grouping_by_cutpoint()
A grouping_strategy object.
pptr, pprf, grouping_by_label
grouping_by_cutpoint()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.