leaf_mean_response: Mean-response leaf strategy.

View source: R/leaf-strategy.R

leaf_mean_responseR Documentation

Mean-response leaf strategy.

Description

Creates a leaf strategy that predicts the mean of the continuous response values for the observations in the leaf. Used for regression trees; requires a numeric response.

Usage

leaf_mean_response()

Value

A leaf_strategy object.

See Also

pptr, pprf, leaf_majority_vote

Examples

leaf_mean_response()


ppforest2 documentation built on July 21, 2026, 9:07 a.m.