oob_predictions: Out-of-bag predictions for a random forest.

View source: R/ppmodel.R

oob_predictionsR Documentation

Out-of-bag predictions for a random forest.

Description

Returns predictions for each training row using only trees that did not see that row in their bootstrap sample. Observations with no OOB tree are represented as 'NA' in both modes: 'NA' at the factor level for classification, and 'NA_real_' for regression. Filter with the standard 'is.na()' idiom.

Usage

oob_predictions(model)

Arguments

model

A pprf forest model.

Value

A factor (classification) or numeric vector (regression), length 'n'.

See Also

oob_error, oob_samples


ppforest2 documentation built on July 21, 2026, 9:07 a.m.