residuals.ppmodel: Residuals from a regression ppforest2 model.

View source: R/ppmodel.R

residuals.ppmodelR Documentation

Residuals from a regression ppforest2 model.

Description

Returns y - fitted(model). Only defined for regression models — classification residuals have no canonical scalar form, so this method errors on classification models rather than inventing a convention.

Usage

## S3 method for class 'ppmodel'
residuals(object, ...)

Arguments

object

A pprf or pptr regression model.

...

Unused.

Value

A numeric vector of length nobs(object).

See Also

fitted.ppmodel


ppforest2 documentation built on July 21, 2026, 9:07 a.m.