View source: R/leaf-strategy.R
| leaf_mean_response | R Documentation |
Creates a leaf strategy that predicts the mean of the continuous response values for the observations in the leaf. Used for regression trees; requires a numeric response.
leaf_mean_response()
A leaf_strategy object.
pptr, pprf, leaf_majority_vote
leaf_mean_response()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.