| oob_predictions | R Documentation |
Returns predictions for each training row using only trees that did not see that row in their bootstrap sample. Observations with no OOB tree are represented as 'NA' in both modes: 'NA' at the factor level for classification, and 'NA_real_' for regression. Filter with the standard 'is.na()' idiom.
oob_predictions(model)
model |
A |
A factor (classification) or numeric vector (regression), length 'n'.
oob_error, oob_samples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.