| predict.pprf_classification | R Documentation |
Predicts labels or vote proportions from a pprf model (classification mode).
## S3 method for class 'pprf_classification'
predict(object, new_data = NULL, type = NULL, ...)
object |
A |
new_data |
A data frame or matrix of new observations. If |
type |
The type of prediction: |
... |
For backward compatibility, the first positional argument is treated as |
If type = "class", a factor of predicted labels. If type = "prob", a data frame with one column per group, each row summing to 1.
pprf, predict.pprf_regression
model <- pprf(Species ~ ., data = iris)
predict(model, iris)
predict(model, iris, type = "prob")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.