| predict.pprf_regression | R Documentation |
Predicts numeric responses from a pprf model (regression mode).
## S3 method for class 'pprf_regression'
predict(object, new_data = NULL, type = NULL, ...)
object |
A |
new_data |
A data frame or matrix of new observations. |
type |
Must be |
... |
For backward compatibility, the first positional argument is treated as |
A numeric vector of mean predictions across the forest's trees.
pprf, predict.pprf_classification
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.