| residuals.ppmodel | R Documentation |
Returns y - fitted(model). Only defined for regression models —
classification residuals have no canonical scalar form, so this method
errors on classification models rather than inventing a convention.
## S3 method for class 'ppmodel'
residuals(object, ...)
object |
A |
... |
Unused. |
A numeric vector of length nobs(object).
fitted.ppmodel
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.