| update.pp_rand_forest | R Documentation |
pp_rand_forest model specification.Implements parsnip's update protocol so that tune::tune_grid()
(and any other caller that finalises a spec via update()) can fill
in the tuned values for trees, mtry, and penalty.
Without this method, update() falls back to stats::update.default
and fails with "need an object with call component".
## S3 method for class 'pp_rand_forest'
update(
object,
parameters = NULL,
trees = NULL,
mtry = NULL,
mtry_prop = NULL,
penalty = NULL,
fresh = FALSE,
...
)
object |
A |
parameters |
A named list of parameters to update (alternative to passing them as args). |
trees, mtry, mtry_prop, penalty |
New values for the corresponding parameters. |
fresh |
If |
... |
Engine-specific arguments to update. |
An updated pp_rand_forest model specification.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.